==> nodebb-theme-slick-1.4.23.tgz: package/lib/theme.js <==
"use strict";

var meta = require.main.require('./src/meta');
var user = require.main.require('./src/user');
var db = require.main.require('./src/database');

var themeSlickSkin = '';

var theme = module.exports;

theme.init = function(params, callback) {

  params.router.get('/admin/plugins/slick', params.middleware.admin.buildHeader, renderAdmin);
  params.router.get('/api/admin/plugins/slick', renderAdmin);

  callback();
};

theme.addAdminNavigation = function(header, callback) {
  header.plugins.push({
    route: '/plugins/slick',
    icon: 'fa-paint-brush',
    name: 'Slick Theme'
  });

  callback(null, header);
};

theme.getThemeConfig = function(config, callback) {
  meta.settings.get('slick', function(err, settings) {
    if (err) {
      return callback(err);
    }
    config.hideSubCategories = settings.hideSubCategories === 'on';
    config.selectedSkin = themeSlickSkin || settings.skinOption || 'default';
    config.bootswatchSkin = '';
    callback(null, config);
  });
};

theme.addUserToTopic = async function (hookData) {
  const settings = await meta.settings.get('persona');
  if (settings.enableQuickReply === 'on') {
    if (hookData.req.user) {
      const userData = await user.getUserData(hookData.req.user.uid);
      hookData.templateData.loggedInUser = userData;
    } else {
      hookData.templateData.loggedInUser =  {
        uid: 0,
        username: '[[global:guest]]',
        picture: user.getDefaultAvatar(),
        'icon:text': '?',
        'icon:bgColor': '#aaa',
      };
    }
  }

  return hookData;
};

theme.customSettings = function(data, callback) {
  var availableSkins = [{
    name: 'Default',
    value: 'default'
  }, {
    name: 'Dark',
    value: 'dark'
  }];

  var options = '';
  var skinSelected;
  availableSkins.forEach(function(skin) {
    skinSelected = (data.settings.themeSlickSkin === skin.value) ? 'selected' : '';
    options = options + '<option value="' + skin.value + '" ' + skinSelected + '>' + skin.name + '</option>';
  });

  data.customSettings.push({
    title: 'Select skin for theme',
    content: '<div class="form-group fg-line"><div class="select"><select data-property="themeSlickSkin" class="form-control"><option value="">None</option>' + options + '</select></div></div>'
  });

  callback(null, data);
};

theme.saveSettings = function(data, callback) {
  db.setObjectField('user:' + data.uid + ':settings', 'themeSlickSkin', data.settings.themeSlickSkin, callback);
};

theme.getSettings = function(data, callback) {
  themeSlickSkin = data.settings.themeSlickSkin;
  callback(null, data);
};

theme.getLinkTags = function(data, callback) {
  data.links.push({
    rel: 'prefetch stylesheet',
    type: '',
    href: 'https://fonts.googleapis.com/css?family=Poppins:300,400,500,600,700&subset=devanagari,latin-ext',
  });

  callback(null, data);
};

function renderAdmin(req, res, next) {
  res.render('admin/plugins/slick', {});
}

==> nodebb-theme-slick-2.0.5.tgz: package/lib/theme.js <==
"use strict";

var meta = require.main.require('./src/meta');
var user = require.main.require('./src/user');
var db = require.main.require('./src/database');

var theme = module.exports;

theme.init = function(params, callback) {

  params.router.get('/admin/plugins/slick', params.middleware.admin.buildHeader, renderAdmin);
  params.router.get('/api/admin/plugins/slick', renderAdmin);

  callback();
};

theme.addAdminNavigation = function(header, callback) {
  header.plugins.push({
    route: '/plugins/slick',
    icon: 'fa-paint-brush',
    name: 'Slick Theme'
  });

  callback(null, header);
};

theme.getThemeConfig = async function(config) {
  const [settings, userSettings] = await Promise.all([
    meta.settings.get('slick'),
    user.getSettings(config.uid),
  ]);
  config.hideSubCategories = settings.hideSubCategories === 'on';
  config.themeSlickSkin = userSettings.themeSlickSkin || settings.skinOption || 'default';
  config.bootswatchSkin = '';
  return config;
};

theme.addUserToTopic = async function (hookData) {
  const settings = await meta.settings.get('persona');
  if (settings.enableQuickReply === 'on') {
    if (hookData.req.user) {
      const userData = await user.getUserData(hookData.req.user.uid);
      hookData.templateData.loggedInUser = userData;
    } else {
      hookData.templateData.loggedInUser =  {
        uid: 0,
        username: '[[global:guest]]',
        picture: user.getDefaultAvatar(),
        'icon:text': '?',
        'icon:bgColor': '#aaa',
      };
    }
  }

  return hookData;
};

theme.customSettings = function(data, callback) {
  var availableSkins = [{
    name: 'Default',
    value: 'default'
  }, {
    name: 'Dark',
    value: 'dark'
  }];

  var options = '';
  var skinSelected;
  availableSkins.forEach(function(skin) {
    skinSelected = (data.settings.themeSlickSkin === skin.value) ? 'selected' : '';
    options = options + '<option value="' + skin.value + '" ' + skinSelected + '>' + skin.name + '</option>';
  });

  data.customSettings.push({
    title: 'Select skin for theme',
    content: '<div class="form-group fg-line"><div class="select"><select data-property="themeSlickSkin" class="form-control"><option value="">None</option>' + options + '</select></div></div>'
  });

  callback(null, data);
};

theme.saveSettings = function(data, callback) {
  db.setObjectField('user:' + data.uid + ':settings', 'themeSlickSkin', data.settings.themeSlickSkin, callback);
};

theme.getLinkTags = function(data, callback) {
  data.links.push({
    rel: 'prefetch stylesheet',
    type: '',
    href: 'https://fonts.googleapis.com/css?family=Poppins:300,400,500,600,700&subset=devanagari,latin-ext',
  });

  callback(null, data);
};

function renderAdmin(req, res, next) {
  res.render('admin/plugins/slick', {});
}
